@@ -260,6 +260,29 @@ namespace paperbox {
         g_debug("rename_tag not implemented yet");
     }
 
+    void
+    Browser::get_all_tags(list<ustring>& tags)
+    {
+        doc_map::iterator it(docs_.begin());
+        doc_map::iterator end(docs_.end());
+
+        for ( ; it != end; ++it) {
+            shared_ptr<Document> doc = it->second;
+            vector<ustring> doc_tags = doc->get_tags();
+
+            vector<ustring>::iterator tit(doc_tags.begin());
+            vector<ustring>::iterator tend(doc_tags.end());
+
+            for ( ; tit != tend; ++tit) {
+                list<ustring>::iterator result =
+                    find(tags.begin(), tags.end(), *tit);
+                if (result == tags.end()) tags.push_back(*tit);
+            }
+        }
+
+        tags.sort();
+    }
+
     void
     Browser::get_all_documents(doc_vector& docs)
     {
